import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASCredentialIdentityStoreState(TestCase):
    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertResultIsBOOL(
            AuthenticationServices.ASCredentialIdentityStoreState.isEnabled
        )
        self.assertResultIsBOOL(
            AuthenticationServices.ASCredentialIdentityStoreState.supportsIncrementalUpdates
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationSecurityKeyPublicKeyCredentialDescriptor(TestCase):
    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationSecurityKeyPublicKeyCredentialDescriptorTransportUSB,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationSecurityKeyPublicKeyCredentialDescriptorTransportNFC,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationSecurityKeyPublicKeyCredentialDescriptorTransportBluetooth,
            str,
        )

    @min_os_level("12.0")
    def test_functions12_0(self):
        AuthenticationServices.ASAuthorizationAllSupportedPublicKeyCredentialDescriptorTransports



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase


class TestASCredentialServiceIdentifier(TestCase):
    def test_constants(self):
        self.assertEqual(
            AuthenticationServices.ASCredentialServiceIdentifierTypeDomain, 0
        )
        self.assertEqual(AuthenticationServices.ASCredentialServiceIdentifierTypeURL, 1)



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationSingleSignOnRequest(TestCase):
    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertResultIsBOOL(
            AuthenticationServices.ASAuthorizationSingleSignOnRequest.isUserInterfaceEnabled
        )
        self.assertArgIsBOOL(
            AuthenticationServices.ASAuthorizationSingleSignOnRequest.setUserInterfaceEnabled_,
            0,
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestASCredentialIdentityStore(TestCase):
    def test_constants(self):
        self.assertEqual(
            AuthenticationServices.ASCredentialIdentityStoreErrorCodeInternalError, 0
        )
        self.assertEqual(
            AuthenticationServices.ASCredentialIdentityStoreErrorCodeStoreDisabled, 1
        )
        self.assertEqual(
            AuthenticationServices.ASCredentialIdentityStoreErrorCodeStoreBusy, 2
        )

    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialIdentityStore.getCredentialIdentityStoreStateWithCompletion_,
            0,
            b"v@",
        )
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialIdentityStore.saveCredentialIdentities_completion_,
            1,
            b"v" + objc._C_NSBOOL + b"@",
        )
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialIdentityStore.removeCredentialIdentities_completion_,
            1,
            b"v" + objc._C_NSBOOL + b"@",
        )
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialIdentityStore.removeAllCredentialIdentitiesWithCompletion_,
            0,
            b"v" + objc._C_NSBOOL + b"@",
        )
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialIdentityStore.replaceCredentialIdentitiesWithIdentities_completion_,
            1,
            b"v" + objc._C_NSBOOL + b"@",
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASExtensionErrors(TestCase):
    def test_constants(self):
        self.assertEqual(AuthenticationServices.ASExtensionErrorCodeFailed, 0)
        self.assertEqual(AuthenticationServices.ASExtensionErrorCodeUserCanceled, 1)
        self.assertEqual(
            AuthenticationServices.ASExtensionErrorCodeUserInteractionRequired, 100
        )
        self.assertEqual(
            AuthenticationServices.ASExtensionErrorCodeCredentialIdentityNotFound, 101
        )

    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(AuthenticationServices.ASExtensionErrorDomain, str)
        self.assertIsInstance(
            AuthenticationServices.ASExtensionLocalizedFailureReasonErrorKey, str
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase


class TestASAuthorizationAppleIDCredential(TestCase):
    def test_constants(self):
        self.assertEqual(AuthenticationServices.ASUserDetectionStatusUnsupported, 0)
        self.assertEqual(AuthenticationServices.ASUserDetectionStatusUnknown, 1)
        self.assertEqual(AuthenticationServices.ASUserDetectionStatusLikelyReal, 2)



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASCOSEConstants(TestCase):
    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertEqual(AuthenticationServices.ASCOSEAlgorithmIdentifierES256, -7)

        self.assertEqual(AuthenticationServices.ASCOSEEllipticCurveIdentifierP256, 1)



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationPublicKeyCredentialConstants(TestCase):
    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialUserVerificationPreferencePreferred,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialUserVerificationPreferenceRequired,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialUserVerificationPreferenceDiscouraged,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialAttestationKindNone,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialAttestationKindDirect,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialAttestationKindIndirect,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialAttestationKindEnterprise,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialResidentKeyPreferenceDiscouraged,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialResidentKeyPreferencePreferred,
            str,
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationPublicKeyCredentialResidentKeyPreferenceRequired,
            str,
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestASCredentialProviderExtensionContext(TestCase):
    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialProviderExtensionContext.completeRequestWithSelectedCredential_completionHandler_,
            1,
            b"v" + objc._C_NSBOOL,
        )
        self.assertArgIsBlock(
            AuthenticationServices.ASCredentialProviderExtensionContext.completeRequestReturningItems_completionHandler_,
            1,
            b"v" + objc._C_NSBOOL,
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationSingleSignOnProvider(TestCase):
    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertResultIsBOOL(
            AuthenticationServices.ASAuthorizationSingleSignOnProvider.canPerformAuthorization
        )



import AuthenticationServices
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationAppleIDProvider(TestCase):
    def test_constants(self):
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDProviderCredentialRevoked, 0
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDProviderCredentialAuthorized, 1
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDProviderCredentialNotFound, 2
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDProviderCredentialTransferred,
            3,
        )

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsBlock(
            AuthenticationServices.ASAuthorizationAppleIDProvider.getCredentialStateForUserID_completion_,  # noqa: B950
            1,
            b"v" + objc._C_NSInteger + b"@",
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase


class TestASAuthorization(TestCase):
    def test_constants(self):
        self.assertEqual(AuthenticationServices.ASAuthorizationErrorUnknown, 1000)
        self.assertEqual(AuthenticationServices.ASAuthorizationErrorCanceled, 1001)
        self.assertEqual(
            AuthenticationServices.ASAuthorizationErrorInvalidResponse, 1002
        )
        self.assertEqual(AuthenticationServices.ASAuthorizationErrorNotHandled, 1003)
        self.assertEqual(AuthenticationServices.ASAuthorizationErrorFailed, 1004)
        self.assertEqual(
            AuthenticationServices.ASAuthorizationErrorNotInteractive, 1005
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationProviderExtensionAuthorizationRequest(TestCase):
    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationProviderAuthorizationOperationConfigurationRemoved,
            str,
        )

    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertResultIsBOOL(
            AuthenticationServices.ASAuthorizationProviderExtensionAuthorizationRequest.isCallerManaged
        )



# This file is generated by objective.metadata
#
# Last update: Sat Jul 31 12:28:05 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a


else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$ASAuthorizationAppleIDProviderCredentialRevokedNotification$ASAuthorizationCustomMethodOther$ASAuthorizationCustomMethodRestorePurchase$ASAuthorizationCustomMethodVideoSubscriberAccount$ASAuthorizationErrorDomain$ASAuthorizationOperationImplicit$ASAuthorizationOperationLogin$ASAuthorizationOperationLogout$ASAuthorizationOperationRefresh$ASAuthorizationProviderAuthorizationOperationConfigurationRemoved$ASAuthorizationPublicKeyCredentialAttestationKindDirect$ASAuthorizationPublicKeyCredentialAttestationKindEnterprise$ASAuthorizationPublicKeyCredentialAttestationKindIndirect$ASAuthorizationPublicKeyCredentialAttestationKindNone$ASAuthorizationPublicKeyCredentialResidentKeyPreferenceDiscouraged$ASAuthorizationPublicKeyCredentialResidentKeyPreferencePreferred$ASAuthorizationPublicKeyCredentialResidentKeyPreferenceRequired$ASAuthorizationPublicKeyCredentialUserVerificationPreferenceDiscouraged$ASAuthorizationPublicKeyCredentialUserVerificationPreferencePreferred$ASAuthorizationPublicKeyCredentialUserVerificationPreferenceRequired$ASAuthorizationScopeEmail$ASAuthorizationScopeFullName$ASAuthorizationSecurityKeyPublicKeyCredentialDescriptorTransportBluetooth$ASAuthorizationSecurityKeyPublicKeyCredentialDescriptorTransportNFC$ASAuthorizationSecurityKeyPublicKeyCredentialDescriptorTransportUSB$ASCredentialIdentityStoreErrorDomain$ASExtensionErrorDomain$ASExtensionLocalizedFailureReasonErrorKey$ASWebAuthenticationSessionErrorDomain$"""
enums = """$ASAuthorizationAppleIDButtonStyleBlack@2$ASAuthorizationAppleIDButtonStyleWhite@0$ASAuthorizationAppleIDButtonStyleWhiteOutline@1$ASAuthorizationAppleIDButtonTypeContinue@1$ASAuthorizationAppleIDButtonTypeDefault@0$ASAuthorizationAppleIDButtonTypeSignIn@0$ASAuthorizationAppleIDButtonTypeSignUp@2$ASAuthorizationAppleIDProviderCredentialAuthorized@1$ASAuthorizationAppleIDProviderCredentialNotFound@2$ASAuthorizationAppleIDProviderCredentialRevoked@0$ASAuthorizationAppleIDProviderCredentialTransferred@3$ASAuthorizationErrorCanceled@1001$ASAuthorizationErrorFailed@1004$ASAuthorizationErrorInvalidResponse@1002$ASAuthorizationErrorNotHandled@1003$ASAuthorizationErrorNotInteractive@1005$ASAuthorizationErrorUnknown@1000$ASCOSEAlgorithmIdentifierES256@-7$ASCOSEEllipticCurveIdentifierP256@1$ASCredentialIdentityStoreErrorCodeInternalError@0$ASCredentialIdentityStoreErrorCodeStoreBusy@2$ASCredentialIdentityStoreErrorCodeStoreDisabled@1$ASCredentialServiceIdentifierTypeDomain@0$ASCredentialServiceIdentifierTypeURL@1$ASExtensionErrorCodeCredentialIdentityNotFound@101$ASExtensionErrorCodeFailed@0$ASExtensionErrorCodeUserCanceled@1$ASExtensionErrorCodeUserInteractionRequired@100$ASUserDetectionStatusLikelyReal@2$ASUserDetectionStatusUnknown@1$ASUserDetectionStatusUnsupported@0$ASWebAuthenticationSessionErrorCodeCanceledLogin@1$ASWebAuthenticationSessionErrorCodePresentationContextInvalid@3$ASWebAuthenticationSessionErrorCodePresentationContextNotProvided@2$"""
misc.update({})
functions = {
    "ASAuthorizationAllSupportedPublicKeyCredentialDescriptorTransports": (b"@",)
}
aliases = {
    "ASAuthorizationAppleIDButtonTypeDefault": "ASAuthorizationAppleIDButtonTypeSignIn"
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"ASAccountAuthenticationModificationExtensionContext",
        b"getSignInWithAppleUpgradeAuthorizationWithState:nonce:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASAuthorizationAppleIDProvider",
        b"getCredentialStateForUserID:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"q"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASAuthorizationProviderExtensionAuthorizationRequest",
        b"isCallerManaged",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"ASAuthorizationProviderExtensionAuthorizationRequest",
        b"presentAuthorizationViewControllerWithCompletion:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASAuthorizationSingleSignOnProvider",
        b"canPerformAuthorization",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"ASAuthorizationSingleSignOnRequest",
        b"isUserInterfaceEnabled",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"ASAuthorizationSingleSignOnRequest",
        b"setUserInterfaceEnabled:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"ASCredentialIdentityStore",
        b"getCredentialIdentityStoreStateWithCompletion:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"ASCredentialIdentityStore",
        b"removeAllCredentialIdentitiesWithCompletion:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASCredentialIdentityStore",
        b"removeCredentialIdentities:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASCredentialIdentityStore",
        b"replaceCredentialIdentitiesWithIdentities:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASCredentialIdentityStore",
        b"saveCredentialIdentities:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"ASCredentialIdentityStoreState", b"isEnabled", {"retval": {"type": b"Z"}})
    r(
        b"ASCredentialIdentityStoreState",
        b"supportsIncrementalUpdates",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"ASCredentialProviderExtensionContext",
        b"completeRequestReturningItems:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    }
                }
            }
        },
    )
    r(
        b"ASCredentialProviderExtensionContext",
        b"completeRequestWithSelectedCredential:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    }
                }
            }
        },
    )
    r(b"ASWebAuthenticationSession", b"canStart", {"retval": {"type": "Z"}})
    r(
        b"ASWebAuthenticationSession",
        b"initWithURL:callbackURLScheme:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"ASWebAuthenticationSession",
        b"prefersEphemeralWebBrowserSession",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"ASWebAuthenticationSession",
        b"setPrefersEphemeralWebBrowserSession:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"ASWebAuthenticationSession", b"start", {"retval": {"type": b"Z"}})
    r(
        b"ASWebAuthenticationSessionRequest",
        b"shouldUseEphemeralSession",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"ASWebAuthenticationSessionWebBrowserSessionManager",
        b"wasLaunchedByAuthenticationServices",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"NSObject",
        b"accountAuthenticationModificationController:didFailRequest:withError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"accountAuthenticationModificationController:didSuccessfullyCompleteRequest:withUserInfo:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(b"NSObject", b"allowedCredentials", {"required": True, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"attestationPreference",
        {"required": True, "retval": {"type": b"@"}},
    )
    r(
        b"NSObject",
        b"authenticationSessionRequest:didCancelWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"authenticationSessionRequest:didCompleteWithCallbackURL:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"authorizationController:didCompleteWithAuthorization:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"authorizationController:didCompleteWithCustomMethod:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"authorizationController:didCompleteWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"beginAuthorizationWithRequest:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"beginHandlingWebAuthenticationSessionRequest:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"cancelAuthorizationWithRequest:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"cancelWebAuthenticationSessionRequest:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"challenge", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"credentialID", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"displayName", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"name", {"required": True, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"presentationAnchorForAccountAuthenticationModificationController:",
        {"required": True, "retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"presentationAnchorForAuthorizationController:",
        {"required": True, "retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"presentationAnchorForWebAuthenticationSession:",
        {"required": True, "retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"rawAttestationObject",
        {"required": True, "retval": {"type": b"@"}},
    )
    r(
        b"NSObject",
        b"rawAuthenticatorData",
        {"required": True, "retval": {"type": b"@"}},
    )
    r(b"NSObject", b"rawClientDataJSON", {"required": True, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"relyingPartyIdentifier",
        {"required": True, "retval": {"type": b"@"}},
    )
    r(
        b"NSObject",
        b"setAllowedCredentials:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setAttestationPreference:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setChallenge:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setCredentialID:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setDisplayName:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setName:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setRelyingPartyIdentifier:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setUserID:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setUserVerificationPreference:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"signature", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"userID", {"required": True, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"userVerificationPreference",
        {"required": True, "retval": {"type": b"@"}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorizationOpenIDRequest(TestCase):
    @min_os_level("10.15")
    def test_constants10_15(self):
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationOperationImplicit, str
        )
        self.assertIsInstance(AuthenticationServices.ASAuthorizationOperationLogin, str)
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationOperationRefresh, str
        )
        self.assertIsInstance(
            AuthenticationServices.ASAuthorizationOperationLogout, str
        )



import AuthenticationServices
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level


class TestASAuthorizationProvider(TestCase):
    @min_sdk_level("10.15")
    def test_protocols(self):
        objc.protocolNamed("ASAuthorizationProvider")

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsBlock(
            AuthenticationServices.ASAuthorizationProviderExtensionAuthorizationRequest.presentAuthorizationViewControllerWithCompletion_,  # noqa: B950
            0,
            b"vZ@",
        )



import AuthenticationServices
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level

ASWebAuthenticationSessionCompletionHandler = b"v@@"


class TestASWebAuthenticationSession(TestCase):
    def test_constants(self):
        self.assertEqual(
            AuthenticationServices.ASWebAuthenticationSessionErrorCodeCanceledLogin, 1
        )
        self.assertEqual(
            AuthenticationServices.ASWebAuthenticationSessionErrorCodePresentationContextNotProvided,  # noqa: B950
            2,
        )
        self.assertEqual(
            AuthenticationServices.ASWebAuthenticationSessionErrorCodePresentationContextInvalid,  # noqa: B950
            3,
        )

    @min_sdk_level("10.15")
    def test_protocols(self):
        objc.protocolNamed("ASWebAuthenticationPresentationContextProviding")

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsBlock(
            AuthenticationServices.ASWebAuthenticationSession.initWithURL_callbackURLScheme_completionHandler_,  # noqa: B950
            2,
            ASWebAuthenticationSessionCompletionHandler,
        )

        self.assertResultIsBOOL(
            AuthenticationServices.ASWebAuthenticationSession.prefersEphemeralWebBrowserSession
        )
        self.assertArgIsBOOL(
            AuthenticationServices.ASWebAuthenticationSession.setPrefersEphemeralWebBrowserSession_,  # noqa: B950
            0,
        )

        self.assertResultIsBOOL(AuthenticationServices.ASWebAuthenticationSession.start)

    @min_os_level("10.15.4")
    def test_methods10_15_4(self):
        self.assertResultIsBOOL(
            AuthenticationServices.ASWebAuthenticationSession.canStart
        )



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase


class TestASAuthorizationAppleIDButton(TestCase):
    def test_constants(self):
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonTypeSignIn, 0
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonTypeContinue, 1
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonTypeSignUp, 2
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonTypeDefault,
            AuthenticationServices.ASAuthorizationAppleIDButtonTypeSignIn,
        )

        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonStyleWhite, 0
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonStyleWhiteOutline, 1
        )
        self.assertEqual(
            AuthenticationServices.ASAuthorizationAppleIDButtonStyleBlack, 2
        )



import AuthenticationServices  # noqa: F401
import objc
from PyObjCTools.TestSupport import TestCase, min_sdk_level


class TestASAuthorizationPublicKeyCredentialDescriptor(TestCase):
    @min_sdk_level("12.0")
    def test_protocols(self):
        objc.protocolNamed("ASAuthorizationPublicKeyCredentialDescriptor")



import AuthenticationServices
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestASAuthorization(TestCase):
    @min_os_level("10.15")
    def test_constants10_15(self):
        self.assertIsInstance(AuthenticationServices.ASAuthorizationScopeFullName, str)
        self.assertIsInstance(AuthenticationServices.ASAuthorizationScopeEmail, str)



import AuthenticationServices  # noqa: F401
from PyObjCTools.TestSupport import TestCase, min_sdk_level
import objc


class TestASPublicKeyCredential(TestCase):
    @min_sdk_level("12.0")
    def test_protocols(self):
        objc.protocolNamed("ASPublicKeyCredential")
